@@ -5,7 +5,7 @@ use warnings;
 
 use parent 'Test::More';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub import {
     my $class = shift;
@@ -27,9 +27,6 @@ sub import {
     require Test::Exception;
     Test::Exception->export_to_level(1);
 
-    require Test::Deep;
-    Test::Deep->export_to_level(1);
-
     require Test::Warnings;
 
     return;
